# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTIdentityManagementParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'metadata_must_be_signed': 'bool',
        'enabled': 'bool',
        'provider_type': 'int',
        'idp_certificate': 'str',
        'idp_entity_id': 'str',
        'idp_redirect_url': 'str'
    }

    attribute_map = {
        'name': 'name',
        'metadata_must_be_signed': 'metadataMustBeSigned',
        'enabled': 'enabled',
        'provider_type': 'providerType',
        'idp_certificate': 'idpCertificate',
        'idp_entity_id': 'idpEntityId',
        'idp_redirect_url': 'idpRedirectURL'
    }

    def __init__(self, name=None, metadata_must_be_signed=None, enabled=None, provider_type=None, idp_certificate=None, idp_entity_id=None, idp_redirect_url=None):  # noqa: E501
        """BTIdentityManagementParams - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._metadata_must_be_signed = None
        self._enabled = None
        self._provider_type = None
        self._idp_certificate = None
        self._idp_entity_id = None
        self._idp_redirect_url = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if metadata_must_be_signed is not None:
            self.metadata_must_be_signed = metadata_must_be_signed
        if enabled is not None:
            self.enabled = enabled
        if provider_type is not None:
            self.provider_type = provider_type
        if idp_certificate is not None:
            self.idp_certificate = idp_certificate
        if idp_entity_id is not None:
            self.idp_entity_id = idp_entity_id
        if idp_redirect_url is not None:
            self.idp_redirect_url = idp_redirect_url

    @property
    def name(self):
        """Gets the name of this BTIdentityManagementParams.  # noqa: E501


        :return: The name of this BTIdentityManagementParams.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTIdentityManagementParams.


        :param name: The name of this BTIdentityManagementParams.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def metadata_must_be_signed(self):
        """Gets the metadata_must_be_signed of this BTIdentityManagementParams.  # noqa: E501


        :return: The metadata_must_be_signed of this BTIdentityManagementParams.  # noqa: E501
        :rtype: bool
        """
        return self._metadata_must_be_signed

    @metadata_must_be_signed.setter
    def metadata_must_be_signed(self, metadata_must_be_signed):
        """Sets the metadata_must_be_signed of this BTIdentityManagementParams.


        :param metadata_must_be_signed: The metadata_must_be_signed of this BTIdentityManagementParams.  # noqa: E501
        :type: bool
        """

        self._metadata_must_be_signed = metadata_must_be_signed

    @property
    def enabled(self):
        """Gets the enabled of this BTIdentityManagementParams.  # noqa: E501


        :return: The enabled of this BTIdentityManagementParams.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this BTIdentityManagementParams.


        :param enabled: The enabled of this BTIdentityManagementParams.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def provider_type(self):
        """Gets the provider_type of this BTIdentityManagementParams.  # noqa: E501


        :return: The provider_type of this BTIdentityManagementParams.  # noqa: E501
        :rtype: int
        """
        return self._provider_type

    @provider_type.setter
    def provider_type(self, provider_type):
        """Sets the provider_type of this BTIdentityManagementParams.


        :param provider_type: The provider_type of this BTIdentityManagementParams.  # noqa: E501
        :type: int
        """

        self._provider_type = provider_type

    @property
    def idp_certificate(self):
        """Gets the idp_certificate of this BTIdentityManagementParams.  # noqa: E501


        :return: The idp_certificate of this BTIdentityManagementParams.  # noqa: E501
        :rtype: str
        """
        return self._idp_certificate

    @idp_certificate.setter
    def idp_certificate(self, idp_certificate):
        """Sets the idp_certificate of this BTIdentityManagementParams.


        :param idp_certificate: The idp_certificate of this BTIdentityManagementParams.  # noqa: E501
        :type: str
        """

        self._idp_certificate = idp_certificate

    @property
    def idp_entity_id(self):
        """Gets the idp_entity_id of this BTIdentityManagementParams.  # noqa: E501


        :return: The idp_entity_id of this BTIdentityManagementParams.  # noqa: E501
        :rtype: str
        """
        return self._idp_entity_id

    @idp_entity_id.setter
    def idp_entity_id(self, idp_entity_id):
        """Sets the idp_entity_id of this BTIdentityManagementParams.


        :param idp_entity_id: The idp_entity_id of this BTIdentityManagementParams.  # noqa: E501
        :type: str
        """

        self._idp_entity_id = idp_entity_id

    @property
    def idp_redirect_url(self):
        """Gets the idp_redirect_url of this BTIdentityManagementParams.  # noqa: E501


        :return: The idp_redirect_url of this BTIdentityManagementParams.  # noqa: E501
        :rtype: str
        """
        return self._idp_redirect_url

    @idp_redirect_url.setter
    def idp_redirect_url(self, idp_redirect_url):
        """Sets the idp_redirect_url of this BTIdentityManagementParams.


        :param idp_redirect_url: The idp_redirect_url of this BTIdentityManagementParams.  # noqa: E501
        :type: str
        """

        self._idp_redirect_url = idp_redirect_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTIdentityManagementParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTNotificationParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'acknowledged': 'bool',
        'expanded': 'bool',
        'campaign_id': 'str',
        'message_id': 'str',
        'message_params_array': 'list[object]',
        'notification_level': 'str',
        'deliver_at': 'datetime',
        'event_key': 'str',
        'message_params': 'list[object]'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'acknowledged': 'acknowledged',
        'expanded': 'expanded',
        'campaign_id': 'campaignId',
        'message_id': 'messageId',
        'message_params_array': 'messageParamsArray',
        'notification_level': 'notificationLevel',
        'deliver_at': 'deliverAt',
        'event_key': 'eventKey',
        'message_params': 'messageParams'
    }

    def __init__(self, id=None, user_id=None, acknowledged=None, expanded=None, campaign_id=None, message_id=None, message_params_array=None, notification_level=None, deliver_at=None, event_key=None, message_params=None):  # noqa: E501
        """BTNotificationParams - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._user_id = None
        self._acknowledged = None
        self._expanded = None
        self._campaign_id = None
        self._message_id = None
        self._message_params_array = None
        self._notification_level = None
        self._deliver_at = None
        self._event_key = None
        self._message_params = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if user_id is not None:
            self.user_id = user_id
        if acknowledged is not None:
            self.acknowledged = acknowledged
        if expanded is not None:
            self.expanded = expanded
        if campaign_id is not None:
            self.campaign_id = campaign_id
        if message_id is not None:
            self.message_id = message_id
        if message_params_array is not None:
            self.message_params_array = message_params_array
        if notification_level is not None:
            self.notification_level = notification_level
        if deliver_at is not None:
            self.deliver_at = deliver_at
        if event_key is not None:
            self.event_key = event_key
        if message_params is not None:
            self.message_params = message_params

    @property
    def id(self):
        """Gets the id of this BTNotificationParams.  # noqa: E501


        :return: The id of this BTNotificationParams.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTNotificationParams.


        :param id: The id of this BTNotificationParams.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this BTNotificationParams.  # noqa: E501


        :return: The user_id of this BTNotificationParams.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this BTNotificationParams.


        :param user_id: The user_id of this BTNotificationParams.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def acknowledged(self):
        """Gets the acknowledged of this BTNotificationParams.  # noqa: E501


        :return: The acknowledged of this BTNotificationParams.  # noqa: E501
        :rtype: bool
        """
        return self._acknowledged

    @acknowledged.setter
    def acknowledged(self, acknowledged):
        """Sets the acknowledged of this BTNotificationParams.


        :param acknowledged: The acknowledged of this BTNotificationParams.  # noqa: E501
        :type: bool
        """

        self._acknowledged = acknowledged

    @property
    def expanded(self):
        """Gets the expanded of this BTNotificationParams.  # noqa: E501


        :return: The expanded of this BTNotificationParams.  # noqa: E501
        :rtype: bool
        """
        return self._expanded

    @expanded.setter
    def expanded(self, expanded):
        """Sets the expanded of this BTNotificationParams.


        :param expanded: The expanded of this BTNotificationParams.  # noqa: E501
        :type: bool
        """

        self._expanded = expanded

    @property
    def campaign_id(self):
        """Gets the campaign_id of this BTNotificationParams.  # noqa: E501


        :return: The campaign_id of this BTNotificationParams.  # noqa: E501
        :rtype: str
        """
        return self._campaign_id

    @campaign_id.setter
    def campaign_id(self, campaign_id):
        """Sets the campaign_id of this BTNotificationParams.


        :param campaign_id: The campaign_id of this BTNotificationParams.  # noqa: E501
        :type: str
        """

        self._campaign_id = campaign_id

    @property
    def message_id(self):
        """Gets the message_id of this BTNotificationParams.  # noqa: E501


        :return: The message_id of this BTNotificationParams.  # noqa: E501
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """Sets the message_id of this BTNotificationParams.


        :param message_id: The message_id of this BTNotificationParams.  # noqa: E501
        :type: str
        """

        self._message_id = message_id

    @property
    def message_params_array(self):
        """Gets the message_params_array of this BTNotificationParams.  # noqa: E501


        :return: The message_params_array of this BTNotificationParams.  # noqa: E501
        :rtype: list[object]
        """
        return self._message_params_array

    @message_params_array.setter
    def message_params_array(self, message_params_array):
        """Sets the message_params_array of this BTNotificationParams.


        :param message_params_array: The message_params_array of this BTNotificationParams.  # noqa: E501
        :type: list[object]
        """

        self._message_params_array = message_params_array

    @property
    def notification_level(self):
        """Gets the notification_level of this BTNotificationParams.  # noqa: E501


        :return: The notification_level of this BTNotificationParams.  # noqa: E501
        :rtype: str
        """
        return self._notification_level

    @notification_level.setter
    def notification_level(self, notification_level):
        """Sets the notification_level of this BTNotificationParams.


        :param notification_level: The notification_level of this BTNotificationParams.  # noqa: E501
        :type: str
        """
        allowed_values = ["INFO", "WARNING", "ERROR", "MARKETING", "PRODUCT", "IMPORTANT", "ACTION"]  # noqa: E501
        if notification_level not in allowed_values:
            raise ValueError(
                "Invalid value for `notification_level` ({0}), must be one of {1}"  # noqa: E501
                .format(notification_level, allowed_values)
            )

        self._notification_level = notification_level

    @property
    def deliver_at(self):
        """Gets the deliver_at of this BTNotificationParams.  # noqa: E501


        :return: The deliver_at of this BTNotificationParams.  # noqa: E501
        :rtype: datetime
        """
        return self._deliver_at

    @deliver_at.setter
    def deliver_at(self, deliver_at):
        """Sets the deliver_at of this BTNotificationParams.


        :param deliver_at: The deliver_at of this BTNotificationParams.  # noqa: E501
        :type: datetime
        """

        self._deliver_at = deliver_at

    @property
    def event_key(self):
        """Gets the event_key of this BTNotificationParams.  # noqa: E501


        :return: The event_key of this BTNotificationParams.  # noqa: E501
        :rtype: str
        """
        return self._event_key

    @event_key.setter
    def event_key(self, event_key):
        """Sets the event_key of this BTNotificationParams.


        :param event_key: The event_key of this BTNotificationParams.  # noqa: E501
        :type: str
        """

        self._event_key = event_key

    @property
    def message_params(self):
        """Gets the message_params of this BTNotificationParams.  # noqa: E501


        :return: The message_params of this BTNotificationParams.  # noqa: E501
        :rtype: list[object]
        """
        return self._message_params

    @message_params.setter
    def message_params(self, message_params):
        """Sets the message_params of this BTNotificationParams.


        :param message_params: The message_params of this BTNotificationParams.  # noqa: E501
        :type: list[object]
        """

        self._message_params = message_params

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTNotificationParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTReleasePackageItemInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'properties': 'list[BTMetadataPropertyInfo]',
        'element_type': 'int',
        'mime_type': 'str',
        'configuration': 'str',
        'company_id': 'str',
        'configuration_key': 'str',
        'workspace_id': 'str',
        'element_id': 'str',
        'document_id': 'str',
        'version_id': 'str',
        'part_id': 'str',
        'small_thumbnail_href': 'str',
        'is_revision_managed': 'bool',
        'errors': 'list[BTReleasePackageItemError]',
        'is_included_editable': 'bool',
        'diff_thumbnail_configuration_key': 'str',
        'rpid': 'str',
        'obsoletion_revision_id': 'str',
        'name': 'str',
        'id': 'str',
        'href': 'str',
        'view_ref': 'str'
    }

    attribute_map = {
        'properties': 'properties',
        'element_type': 'elementType',
        'mime_type': 'mimeType',
        'configuration': 'configuration',
        'company_id': 'companyId',
        'configuration_key': 'configurationKey',
        'workspace_id': 'workspaceId',
        'element_id': 'elementId',
        'document_id': 'documentId',
        'version_id': 'versionId',
        'part_id': 'partId',
        'small_thumbnail_href': 'smallThumbnailHref',
        'is_revision_managed': 'isRevisionManaged',
        'errors': 'errors',
        'is_included_editable': 'isIncludedEditable',
        'diff_thumbnail_configuration_key': 'diffThumbnailConfigurationKey',
        'rpid': 'rpid',
        'obsoletion_revision_id': 'obsoletionRevisionId',
        'name': 'name',
        'id': 'id',
        'href': 'href',
        'view_ref': 'viewRef'
    }

    def __init__(self, properties=None, element_type=None, mime_type=None, configuration=None, company_id=None, configuration_key=None, workspace_id=None, element_id=None, document_id=None, version_id=None, part_id=None, small_thumbnail_href=None, is_revision_managed=None, errors=None, is_included_editable=None, diff_thumbnail_configuration_key=None, rpid=None, obsoletion_revision_id=None, name=None, id=None, href=None, view_ref=None):  # noqa: E501
        """BTReleasePackageItemInfo - a model defined in OpenAPI"""  # noqa: E501

        self._properties = None
        self._element_type = None
        self._mime_type = None
        self._configuration = None
        self._company_id = None
        self._configuration_key = None
        self._workspace_id = None
        self._element_id = None
        self._document_id = None
        self._version_id = None
        self._part_id = None
        self._small_thumbnail_href = None
        self._is_revision_managed = None
        self._errors = None
        self._is_included_editable = None
        self._diff_thumbnail_configuration_key = None
        self._rpid = None
        self._obsoletion_revision_id = None
        self._name = None
        self._id = None
        self._href = None
        self._view_ref = None
        self.discriminator = None

        if properties is not None:
            self.properties = properties
        if element_type is not None:
            self.element_type = element_type
        if mime_type is not None:
            self.mime_type = mime_type
        if configuration is not None:
            self.configuration = configuration
        if company_id is not None:
            self.company_id = company_id
        if configuration_key is not None:
            self.configuration_key = configuration_key
        if workspace_id is not None:
            self.workspace_id = workspace_id
        if element_id is not None:
            self.element_id = element_id
        if document_id is not None:
            self.document_id = document_id
        if version_id is not None:
            self.version_id = version_id
        if part_id is not None:
            self.part_id = part_id
        if small_thumbnail_href is not None:
            self.small_thumbnail_href = small_thumbnail_href
        if is_revision_managed is not None:
            self.is_revision_managed = is_revision_managed
        if errors is not None:
            self.errors = errors
        if is_included_editable is not None:
            self.is_included_editable = is_included_editable
        if diff_thumbnail_configuration_key is not None:
            self.diff_thumbnail_configuration_key = diff_thumbnail_configuration_key
        if rpid is not None:
            self.rpid = rpid
        if obsoletion_revision_id is not None:
            self.obsoletion_revision_id = obsoletion_revision_id
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if href is not None:
            self.href = href
        if view_ref is not None:
            self.view_ref = view_ref

    @property
    def properties(self):
        """Gets the properties of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The properties of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: list[BTMetadataPropertyInfo]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this BTReleasePackageItemInfo.


        :param properties: The properties of this BTReleasePackageItemInfo.  # noqa: E501
        :type: list[BTMetadataPropertyInfo]
        """

        self._properties = properties

    @property
    def element_type(self):
        """Gets the element_type of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The element_type of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: int
        """
        return self._element_type

    @element_type.setter
    def element_type(self, element_type):
        """Sets the element_type of this BTReleasePackageItemInfo.


        :param element_type: The element_type of this BTReleasePackageItemInfo.  # noqa: E501
        :type: int
        """

        self._element_type = element_type

    @property
    def mime_type(self):
        """Gets the mime_type of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The mime_type of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: str
        """
        return self._mime_type

    @mime_type.setter
    def mime_type(self, mime_type):
        """Sets the mime_type of this BTReleasePackageItemInfo.


        :param mime_type: The mime_type of this BTReleasePackageItemInfo.  # noqa: E501
        :type: str
        """

        self._mime_type = mime_type

    @property
    def configuration(self):
        """Gets the configuration of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The configuration of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: str
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this BTReleasePackageItemInfo.


        :param configuration: The configuration of this BTReleasePackageItemInfo.  # noqa: E501
        :type: str
        """

        self._configuration = configuration

    @property
    def company_id(self):
        """Gets the company_id of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The company_id of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: str
        """
        return self._company_id

    @company_id.setter
    def company_id(self, company_id):
        """Sets the company_id of this BTReleasePackageItemInfo.


        :param company_id: The company_id of this BTReleasePackageItemInfo.  # noqa: E501
        :type: str
        """

        self._company_id = company_id

    @property
    def configuration_key(self):
        """Gets the configuration_key of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The configuration_key of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: str
        """
        return self._configuration_key

    @configuration_key.setter
    def configuration_key(self, configuration_key):
        """Sets the configuration_key of this BTReleasePackageItemInfo.


        :param configuration_key: The configuration_key of this BTReleasePackageItemInfo.  # noqa: E501
        :type: str
        """

        self._configuration_key = configuration_key

    @property
    def workspace_id(self):
        """Gets the workspace_id of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The workspace_id of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: str
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this BTReleasePackageItemInfo.


        :param workspace_id: The workspace_id of this BTReleasePackageItemInfo.  # noqa: E501
        :type: str
        """

        self._workspace_id = workspace_id

    @property
    def element_id(self):
        """Gets the element_id of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The element_id of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: str
        """
        return self._element_id

    @element_id.setter
    def element_id(self, element_id):
        """Sets the element_id of this BTReleasePackageItemInfo.


        :param element_id: The element_id of this BTReleasePackageItemInfo.  # noqa: E501
        :type: str
        """

        self._element_id = element_id

    @property
    def document_id(self):
        """Gets the document_id of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The document_id of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this BTReleasePackageItemInfo.


        :param document_id: The document_id of this BTReleasePackageItemInfo.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def version_id(self):
        """Gets the version_id of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The version_id of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """Sets the version_id of this BTReleasePackageItemInfo.


        :param version_id: The version_id of this BTReleasePackageItemInfo.  # noqa: E501
        :type: str
        """

        self._version_id = version_id

    @property
    def part_id(self):
        """Gets the part_id of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The part_id of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: str
        """
        return self._part_id

    @part_id.setter
    def part_id(self, part_id):
        """Sets the part_id of this BTReleasePackageItemInfo.


        :param part_id: The part_id of this BTReleasePackageItemInfo.  # noqa: E501
        :type: str
        """

        self._part_id = part_id

    @property
    def small_thumbnail_href(self):
        """Gets the small_thumbnail_href of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The small_thumbnail_href of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: str
        """
        return self._small_thumbnail_href

    @small_thumbnail_href.setter
    def small_thumbnail_href(self, small_thumbnail_href):
        """Sets the small_thumbnail_href of this BTReleasePackageItemInfo.


        :param small_thumbnail_href: The small_thumbnail_href of this BTReleasePackageItemInfo.  # noqa: E501
        :type: str
        """

        self._small_thumbnail_href = small_thumbnail_href

    @property
    def is_revision_managed(self):
        """Gets the is_revision_managed of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The is_revision_managed of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_revision_managed

    @is_revision_managed.setter
    def is_revision_managed(self, is_revision_managed):
        """Sets the is_revision_managed of this BTReleasePackageItemInfo.


        :param is_revision_managed: The is_revision_managed of this BTReleasePackageItemInfo.  # noqa: E501
        :type: bool
        """

        self._is_revision_managed = is_revision_managed

    @property
    def errors(self):
        """Gets the errors of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The errors of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: list[BTReleasePackageItemError]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this BTReleasePackageItemInfo.


        :param errors: The errors of this BTReleasePackageItemInfo.  # noqa: E501
        :type: list[BTReleasePackageItemError]
        """

        self._errors = errors

    @property
    def is_included_editable(self):
        """Gets the is_included_editable of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The is_included_editable of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_included_editable

    @is_included_editable.setter
    def is_included_editable(self, is_included_editable):
        """Sets the is_included_editable of this BTReleasePackageItemInfo.


        :param is_included_editable: The is_included_editable of this BTReleasePackageItemInfo.  # noqa: E501
        :type: bool
        """

        self._is_included_editable = is_included_editable

    @property
    def diff_thumbnail_configuration_key(self):
        """Gets the diff_thumbnail_configuration_key of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The diff_thumbnail_configuration_key of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: str
        """
        return self._diff_thumbnail_configuration_key

    @diff_thumbnail_configuration_key.setter
    def diff_thumbnail_configuration_key(self, diff_thumbnail_configuration_key):
        """Sets the diff_thumbnail_configuration_key of this BTReleasePackageItemInfo.


        :param diff_thumbnail_configuration_key: The diff_thumbnail_configuration_key of this BTReleasePackageItemInfo.  # noqa: E501
        :type: str
        """

        self._diff_thumbnail_configuration_key = diff_thumbnail_configuration_key

    @property
    def rpid(self):
        """Gets the rpid of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The rpid of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: str
        """
        return self._rpid

    @rpid.setter
    def rpid(self, rpid):
        """Sets the rpid of this BTReleasePackageItemInfo.


        :param rpid: The rpid of this BTReleasePackageItemInfo.  # noqa: E501
        :type: str
        """

        self._rpid = rpid

    @property
    def obsoletion_revision_id(self):
        """Gets the obsoletion_revision_id of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The obsoletion_revision_id of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: str
        """
        return self._obsoletion_revision_id

    @obsoletion_revision_id.setter
    def obsoletion_revision_id(self, obsoletion_revision_id):
        """Sets the obsoletion_revision_id of this BTReleasePackageItemInfo.


        :param obsoletion_revision_id: The obsoletion_revision_id of this BTReleasePackageItemInfo.  # noqa: E501
        :type: str
        """

        self._obsoletion_revision_id = obsoletion_revision_id

    @property
    def name(self):
        """Gets the name of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The name of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTReleasePackageItemInfo.


        :param name: The name of this BTReleasePackageItemInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The id of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTReleasePackageItemInfo.


        :param id: The id of this BTReleasePackageItemInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def href(self):
        """Gets the href of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The href of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTReleasePackageItemInfo.


        :param href: The href of this BTReleasePackageItemInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def view_ref(self):
        """Gets the view_ref of this BTReleasePackageItemInfo.  # noqa: E501


        :return: The view_ref of this BTReleasePackageItemInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_ref

    @view_ref.setter
    def view_ref(self, view_ref):
        """Sets the view_ref of this BTReleasePackageItemInfo.


        :param view_ref: The view_ref of this BTReleasePackageItemInfo.  # noqa: E501
        :type: str
        """

        self._view_ref = view_ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTReleasePackageItemInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTDocumentParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'generate_unknown_messages': 'bool',
        'is_empty_content': 'bool',
        'description': 'str',
        'tags': 'list[str]',
        'owner_id': 'str',
        'owner_type': 'int',
        'not_revision_managed': 'bool',
        'project_id': 'str',
        'parent_id': 'str',
        'is_public': 'bool',
        'beta_capability_ids': 'list[str]',
        'owner_email': 'str'
    }

    attribute_map = {
        'name': 'name',
        'generate_unknown_messages': 'generateUnknownMessages',
        'is_empty_content': 'isEmptyContent',
        'description': 'description',
        'tags': 'tags',
        'owner_id': 'ownerId',
        'owner_type': 'ownerType',
        'not_revision_managed': 'notRevisionManaged',
        'project_id': 'projectId',
        'parent_id': 'parentId',
        'is_public': 'isPublic',
        'beta_capability_ids': 'betaCapabilityIds',
        'owner_email': 'ownerEmail'
    }

    def __init__(self, name=None, generate_unknown_messages=None, is_empty_content=None, description=None, tags=None, owner_id=None, owner_type=None, not_revision_managed=None, project_id=None, parent_id=None, is_public=None, beta_capability_ids=None, owner_email=None):  # noqa: E501
        """BTDocumentParams - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._generate_unknown_messages = None
        self._is_empty_content = None
        self._description = None
        self._tags = None
        self._owner_id = None
        self._owner_type = None
        self._not_revision_managed = None
        self._project_id = None
        self._parent_id = None
        self._is_public = None
        self._beta_capability_ids = None
        self._owner_email = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if generate_unknown_messages is not None:
            self.generate_unknown_messages = generate_unknown_messages
        if is_empty_content is not None:
            self.is_empty_content = is_empty_content
        if description is not None:
            self.description = description
        if tags is not None:
            self.tags = tags
        if owner_id is not None:
            self.owner_id = owner_id
        if owner_type is not None:
            self.owner_type = owner_type
        if not_revision_managed is not None:
            self.not_revision_managed = not_revision_managed
        if project_id is not None:
            self.project_id = project_id
        if parent_id is not None:
            self.parent_id = parent_id
        if is_public is not None:
            self.is_public = is_public
        if beta_capability_ids is not None:
            self.beta_capability_ids = beta_capability_ids
        if owner_email is not None:
            self.owner_email = owner_email

    @property
    def name(self):
        """Gets the name of this BTDocumentParams.  # noqa: E501


        :return: The name of this BTDocumentParams.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTDocumentParams.


        :param name: The name of this BTDocumentParams.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def generate_unknown_messages(self):
        """Gets the generate_unknown_messages of this BTDocumentParams.  # noqa: E501


        :return: The generate_unknown_messages of this BTDocumentParams.  # noqa: E501
        :rtype: bool
        """
        return self._generate_unknown_messages

    @generate_unknown_messages.setter
    def generate_unknown_messages(self, generate_unknown_messages):
        """Sets the generate_unknown_messages of this BTDocumentParams.


        :param generate_unknown_messages: The generate_unknown_messages of this BTDocumentParams.  # noqa: E501
        :type: bool
        """

        self._generate_unknown_messages = generate_unknown_messages

    @property
    def is_empty_content(self):
        """Gets the is_empty_content of this BTDocumentParams.  # noqa: E501


        :return: The is_empty_content of this BTDocumentParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_empty_content

    @is_empty_content.setter
    def is_empty_content(self, is_empty_content):
        """Sets the is_empty_content of this BTDocumentParams.


        :param is_empty_content: The is_empty_content of this BTDocumentParams.  # noqa: E501
        :type: bool
        """

        self._is_empty_content = is_empty_content

    @property
    def description(self):
        """Gets the description of this BTDocumentParams.  # noqa: E501


        :return: The description of this BTDocumentParams.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTDocumentParams.


        :param description: The description of this BTDocumentParams.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def tags(self):
        """Gets the tags of this BTDocumentParams.  # noqa: E501


        :return: The tags of this BTDocumentParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this BTDocumentParams.


        :param tags: The tags of this BTDocumentParams.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def owner_id(self):
        """Gets the owner_id of this BTDocumentParams.  # noqa: E501


        :return: The owner_id of this BTDocumentParams.  # noqa: E501
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this BTDocumentParams.


        :param owner_id: The owner_id of this BTDocumentParams.  # noqa: E501
        :type: str
        """

        self._owner_id = owner_id

    @property
    def owner_type(self):
        """Gets the owner_type of this BTDocumentParams.  # noqa: E501


        :return: The owner_type of this BTDocumentParams.  # noqa: E501
        :rtype: int
        """
        return self._owner_type

    @owner_type.setter
    def owner_type(self, owner_type):
        """Sets the owner_type of this BTDocumentParams.


        :param owner_type: The owner_type of this BTDocumentParams.  # noqa: E501
        :type: int
        """

        self._owner_type = owner_type

    @property
    def not_revision_managed(self):
        """Gets the not_revision_managed of this BTDocumentParams.  # noqa: E501


        :return: The not_revision_managed of this BTDocumentParams.  # noqa: E501
        :rtype: bool
        """
        return self._not_revision_managed

    @not_revision_managed.setter
    def not_revision_managed(self, not_revision_managed):
        """Sets the not_revision_managed of this BTDocumentParams.


        :param not_revision_managed: The not_revision_managed of this BTDocumentParams.  # noqa: E501
        :type: bool
        """

        self._not_revision_managed = not_revision_managed

    @property
    def project_id(self):
        """Gets the project_id of this BTDocumentParams.  # noqa: E501


        :return: The project_id of this BTDocumentParams.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this BTDocumentParams.


        :param project_id: The project_id of this BTDocumentParams.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def parent_id(self):
        """Gets the parent_id of this BTDocumentParams.  # noqa: E501


        :return: The parent_id of this BTDocumentParams.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this BTDocumentParams.


        :param parent_id: The parent_id of this BTDocumentParams.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def is_public(self):
        """Gets the is_public of this BTDocumentParams.  # noqa: E501


        :return: The is_public of this BTDocumentParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_public

    @is_public.setter
    def is_public(self, is_public):
        """Sets the is_public of this BTDocumentParams.


        :param is_public: The is_public of this BTDocumentParams.  # noqa: E501
        :type: bool
        """

        self._is_public = is_public

    @property
    def beta_capability_ids(self):
        """Gets the beta_capability_ids of this BTDocumentParams.  # noqa: E501


        :return: The beta_capability_ids of this BTDocumentParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._beta_capability_ids

    @beta_capability_ids.setter
    def beta_capability_ids(self, beta_capability_ids):
        """Sets the beta_capability_ids of this BTDocumentParams.


        :param beta_capability_ids: The beta_capability_ids of this BTDocumentParams.  # noqa: E501
        :type: list[str]
        """

        self._beta_capability_ids = beta_capability_ids

    @property
    def owner_email(self):
        """Gets the owner_email of this BTDocumentParams.  # noqa: E501


        :return: The owner_email of this BTDocumentParams.  # noqa: E501
        :rtype: str
        """
        return self._owner_email

    @owner_email.setter
    def owner_email(self, owner_email):
        """Sets the owner_email of this BTDocumentParams.


        :param owner_email: The owner_email of this BTDocumentParams.  # noqa: E501
        :type: str
        """

        self._owner_email = owner_email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTDocumentParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTSendGridDeliveryEventParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ip': 'str',
        'email': 'str',
        'timestamp': 'int',
        'smtpid': 'str',
        'event': 'str'
    }

    attribute_map = {
        'ip': 'ip',
        'email': 'email',
        'timestamp': 'timestamp',
        'smtpid': 'smtpid',
        'event': 'event'
    }

    def __init__(self, ip=None, email=None, timestamp=None, smtpid=None, event=None):  # noqa: E501
        """BTSendGridDeliveryEventParams - a model defined in OpenAPI"""  # noqa: E501

        self._ip = None
        self._email = None
        self._timestamp = None
        self._smtpid = None
        self._event = None
        self.discriminator = None

        if ip is not None:
            self.ip = ip
        if email is not None:
            self.email = email
        if timestamp is not None:
            self.timestamp = timestamp
        if smtpid is not None:
            self.smtpid = smtpid
        if event is not None:
            self.event = event

    @property
    def ip(self):
        """Gets the ip of this BTSendGridDeliveryEventParams.  # noqa: E501


        :return: The ip of this BTSendGridDeliveryEventParams.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this BTSendGridDeliveryEventParams.


        :param ip: The ip of this BTSendGridDeliveryEventParams.  # noqa: E501
        :type: str
        """

        self._ip = ip

    @property
    def email(self):
        """Gets the email of this BTSendGridDeliveryEventParams.  # noqa: E501


        :return: The email of this BTSendGridDeliveryEventParams.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this BTSendGridDeliveryEventParams.


        :param email: The email of this BTSendGridDeliveryEventParams.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def timestamp(self):
        """Gets the timestamp of this BTSendGridDeliveryEventParams.  # noqa: E501


        :return: The timestamp of this BTSendGridDeliveryEventParams.  # noqa: E501
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this BTSendGridDeliveryEventParams.


        :param timestamp: The timestamp of this BTSendGridDeliveryEventParams.  # noqa: E501
        :type: int
        """

        self._timestamp = timestamp

    @property
    def smtpid(self):
        """Gets the smtpid of this BTSendGridDeliveryEventParams.  # noqa: E501


        :return: The smtpid of this BTSendGridDeliveryEventParams.  # noqa: E501
        :rtype: str
        """
        return self._smtpid

    @smtpid.setter
    def smtpid(self, smtpid):
        """Sets the smtpid of this BTSendGridDeliveryEventParams.


        :param smtpid: The smtpid of this BTSendGridDeliveryEventParams.  # noqa: E501
        :type: str
        """

        self._smtpid = smtpid

    @property
    def event(self):
        """Gets the event of this BTSendGridDeliveryEventParams.  # noqa: E501


        :return: The event of this BTSendGridDeliveryEventParams.  # noqa: E501
        :rtype: str
        """
        return self._event

    @event.setter
    def event(self, event):
        """Sets the event of this BTSendGridDeliveryEventParams.


        :param event: The event of this BTSendGridDeliveryEventParams.  # noqa: E501
        :type: str
        """

        self._event = event

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTSendGridDeliveryEventParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTAdminTaskParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'message': 'str',
        'task_name': 'str',
        'force': 'bool',
        'task_names': 'list[str]'
    }

    attribute_map = {
        'message': 'message',
        'task_name': 'taskName',
        'force': 'force',
        'task_names': 'taskNames'
    }

    def __init__(self, message=None, task_name=None, force=None, task_names=None):  # noqa: E501
        """BTAdminTaskParams - a model defined in OpenAPI"""  # noqa: E501

        self._message = None
        self._task_name = None
        self._force = None
        self._task_names = None
        self.discriminator = None

        if message is not None:
            self.message = message
        if task_name is not None:
            self.task_name = task_name
        if force is not None:
            self.force = force
        if task_names is not None:
            self.task_names = task_names

    @property
    def message(self):
        """Gets the message of this BTAdminTaskParams.  # noqa: E501


        :return: The message of this BTAdminTaskParams.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this BTAdminTaskParams.


        :param message: The message of this BTAdminTaskParams.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def task_name(self):
        """Gets the task_name of this BTAdminTaskParams.  # noqa: E501


        :return: The task_name of this BTAdminTaskParams.  # noqa: E501
        :rtype: str
        """
        return self._task_name

    @task_name.setter
    def task_name(self, task_name):
        """Sets the task_name of this BTAdminTaskParams.


        :param task_name: The task_name of this BTAdminTaskParams.  # noqa: E501
        :type: str
        """

        self._task_name = task_name

    @property
    def force(self):
        """Gets the force of this BTAdminTaskParams.  # noqa: E501


        :return: The force of this BTAdminTaskParams.  # noqa: E501
        :rtype: bool
        """
        return self._force

    @force.setter
    def force(self, force):
        """Sets the force of this BTAdminTaskParams.


        :param force: The force of this BTAdminTaskParams.  # noqa: E501
        :type: bool
        """

        self._force = force

    @property
    def task_names(self):
        """Gets the task_names of this BTAdminTaskParams.  # noqa: E501


        :return: The task_names of this BTAdminTaskParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._task_names

    @task_names.setter
    def task_names(self, task_names):
        """Sets the task_names of this BTAdminTaskParams.


        :param task_names: The task_names of this BTAdminTaskParams.  # noqa: E501
        :type: list[str]
        """

        self._task_names = task_names

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTAdminTaskParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTAssemblyTransformDefinitionParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'transform': 'list[float]',
        'occurrences': 'list[BTOccurrence]',
        'is_relative': 'bool'
    }

    attribute_map = {
        'transform': 'transform',
        'occurrences': 'occurrences',
        'is_relative': 'isRelative'
    }

    def __init__(self, transform=None, occurrences=None, is_relative=None):  # noqa: E501
        """BTAssemblyTransformDefinitionParams - a model defined in OpenAPI"""  # noqa: E501

        self._transform = None
        self._occurrences = None
        self._is_relative = None
        self.discriminator = None

        if transform is not None:
            self.transform = transform
        if occurrences is not None:
            self.occurrences = occurrences
        if is_relative is not None:
            self.is_relative = is_relative

    @property
    def transform(self):
        """Gets the transform of this BTAssemblyTransformDefinitionParams.  # noqa: E501


        :return: The transform of this BTAssemblyTransformDefinitionParams.  # noqa: E501
        :rtype: list[float]
        """
        return self._transform

    @transform.setter
    def transform(self, transform):
        """Sets the transform of this BTAssemblyTransformDefinitionParams.


        :param transform: The transform of this BTAssemblyTransformDefinitionParams.  # noqa: E501
        :type: list[float]
        """

        self._transform = transform

    @property
    def occurrences(self):
        """Gets the occurrences of this BTAssemblyTransformDefinitionParams.  # noqa: E501


        :return: The occurrences of this BTAssemblyTransformDefinitionParams.  # noqa: E501
        :rtype: list[BTOccurrence]
        """
        return self._occurrences

    @occurrences.setter
    def occurrences(self, occurrences):
        """Sets the occurrences of this BTAssemblyTransformDefinitionParams.


        :param occurrences: The occurrences of this BTAssemblyTransformDefinitionParams.  # noqa: E501
        :type: list[BTOccurrence]
        """

        self._occurrences = occurrences

    @property
    def is_relative(self):
        """Gets the is_relative of this BTAssemblyTransformDefinitionParams.  # noqa: E501


        :return: The is_relative of this BTAssemblyTransformDefinitionParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_relative

    @is_relative.setter
    def is_relative(self, is_relative):
        """Sets the is_relative of this BTAssemblyTransformDefinitionParams.


        :param is_relative: The is_relative of this BTAssemblyTransformDefinitionParams.  # noqa: E501
        :type: bool
        """

        self._is_relative = is_relative

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTAssemblyTransformDefinitionParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class FormDataBodyPart(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'content_disposition': 'ContentDisposition',
        'entity': 'object',
        'headers': 'BodyPartHeaders',
        'media_type': 'BodyPartMediaType',
        'message_body_workers': 'MessageBodyWorkers',
        'parent': 'MultiPart',
        'providers': 'object',
        'name': 'str',
        'value': 'str',
        'form_data_content_disposition': 'FormDataContentDisposition',
        'simple': 'bool',
        'parameterized_headers': 'BodyPartHeaders'
    }

    attribute_map = {
        'content_disposition': 'contentDisposition',
        'entity': 'entity',
        'headers': 'headers',
        'media_type': 'mediaType',
        'message_body_workers': 'messageBodyWorkers',
        'parent': 'parent',
        'providers': 'providers',
        'name': 'name',
        'value': 'value',
        'form_data_content_disposition': 'formDataContentDisposition',
        'simple': 'simple',
        'parameterized_headers': 'parameterizedHeaders'
    }

    def __init__(self, content_disposition=None, entity=None, headers=None, media_type=None, message_body_workers=None, parent=None, providers=None, name=None, value=None, form_data_content_disposition=None, simple=None, parameterized_headers=None):  # noqa: E501
        """FormDataBodyPart - a model defined in OpenAPI"""  # noqa: E501

        self._content_disposition = None
        self._entity = None
        self._headers = None
        self._media_type = None
        self._message_body_workers = None
        self._parent = None
        self._providers = None
        self._name = None
        self._value = None
        self._form_data_content_disposition = None
        self._simple = None
        self._parameterized_headers = None
        self.discriminator = None

        if content_disposition is not None:
            self.content_disposition = content_disposition
        if entity is not None:
            self.entity = entity
        if headers is not None:
            self.headers = headers
        if media_type is not None:
            self.media_type = media_type
        if message_body_workers is not None:
            self.message_body_workers = message_body_workers
        if parent is not None:
            self.parent = parent
        if providers is not None:
            self.providers = providers
        if name is not None:
            self.name = name
        if value is not None:
            self.value = value
        if form_data_content_disposition is not None:
            self.form_data_content_disposition = form_data_content_disposition
        if simple is not None:
            self.simple = simple
        if parameterized_headers is not None:
            self.parameterized_headers = parameterized_headers

    @property
    def content_disposition(self):
        """Gets the content_disposition of this FormDataBodyPart.  # noqa: E501


        :return: The content_disposition of this FormDataBodyPart.  # noqa: E501
        :rtype: ContentDisposition
        """
        return self._content_disposition

    @content_disposition.setter
    def content_disposition(self, content_disposition):
        """Sets the content_disposition of this FormDataBodyPart.


        :param content_disposition: The content_disposition of this FormDataBodyPart.  # noqa: E501
        :type: ContentDisposition
        """

        self._content_disposition = content_disposition

    @property
    def entity(self):
        """Gets the entity of this FormDataBodyPart.  # noqa: E501


        :return: The entity of this FormDataBodyPart.  # noqa: E501
        :rtype: object
        """
        return self._entity

    @entity.setter
    def entity(self, entity):
        """Sets the entity of this FormDataBodyPart.


        :param entity: The entity of this FormDataBodyPart.  # noqa: E501
        :type: object
        """

        self._entity = entity

    @property
    def headers(self):
        """Gets the headers of this FormDataBodyPart.  # noqa: E501


        :return: The headers of this FormDataBodyPart.  # noqa: E501
        :rtype: BodyPartHeaders
        """
        return self._headers

    @headers.setter
    def headers(self, headers):
        """Sets the headers of this FormDataBodyPart.


        :param headers: The headers of this FormDataBodyPart.  # noqa: E501
        :type: BodyPartHeaders
        """

        self._headers = headers

    @property
    def media_type(self):
        """Gets the media_type of this FormDataBodyPart.  # noqa: E501


        :return: The media_type of this FormDataBodyPart.  # noqa: E501
        :rtype: BodyPartMediaType
        """
        return self._media_type

    @media_type.setter
    def media_type(self, media_type):
        """Sets the media_type of this FormDataBodyPart.


        :param media_type: The media_type of this FormDataBodyPart.  # noqa: E501
        :type: BodyPartMediaType
        """

        self._media_type = media_type

    @property
    def message_body_workers(self):
        """Gets the message_body_workers of this FormDataBodyPart.  # noqa: E501


        :return: The message_body_workers of this FormDataBodyPart.  # noqa: E501
        :rtype: MessageBodyWorkers
        """
        return self._message_body_workers

    @message_body_workers.setter
    def message_body_workers(self, message_body_workers):
        """Sets the message_body_workers of this FormDataBodyPart.


        :param message_body_workers: The message_body_workers of this FormDataBodyPart.  # noqa: E501
        :type: MessageBodyWorkers
        """

        self._message_body_workers = message_body_workers

    @property
    def parent(self):
        """Gets the parent of this FormDataBodyPart.  # noqa: E501


        :return: The parent of this FormDataBodyPart.  # noqa: E501
        :rtype: MultiPart
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this FormDataBodyPart.


        :param parent: The parent of this FormDataBodyPart.  # noqa: E501
        :type: MultiPart
        """

        self._parent = parent

    @property
    def providers(self):
        """Gets the providers of this FormDataBodyPart.  # noqa: E501


        :return: The providers of this FormDataBodyPart.  # noqa: E501
        :rtype: object
        """
        return self._providers

    @providers.setter
    def providers(self, providers):
        """Sets the providers of this FormDataBodyPart.


        :param providers: The providers of this FormDataBodyPart.  # noqa: E501
        :type: object
        """

        self._providers = providers

    @property
    def name(self):
        """Gets the name of this FormDataBodyPart.  # noqa: E501


        :return: The name of this FormDataBodyPart.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FormDataBodyPart.


        :param name: The name of this FormDataBodyPart.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def value(self):
        """Gets the value of this FormDataBodyPart.  # noqa: E501


        :return: The value of this FormDataBodyPart.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this FormDataBodyPart.


        :param value: The value of this FormDataBodyPart.  # noqa: E501
        :type: str
        """

        self._value = value

    @property
    def form_data_content_disposition(self):
        """Gets the form_data_content_disposition of this FormDataBodyPart.  # noqa: E501


        :return: The form_data_content_disposition of this FormDataBodyPart.  # noqa: E501
        :rtype: FormDataContentDisposition
        """
        return self._form_data_content_disposition

    @form_data_content_disposition.setter
    def form_data_content_disposition(self, form_data_content_disposition):
        """Sets the form_data_content_disposition of this FormDataBodyPart.


        :param form_data_content_disposition: The form_data_content_disposition of this FormDataBodyPart.  # noqa: E501
        :type: FormDataContentDisposition
        """

        self._form_data_content_disposition = form_data_content_disposition

    @property
    def simple(self):
        """Gets the simple of this FormDataBodyPart.  # noqa: E501


        :return: The simple of this FormDataBodyPart.  # noqa: E501
        :rtype: bool
        """
        return self._simple

    @simple.setter
    def simple(self, simple):
        """Sets the simple of this FormDataBodyPart.


        :param simple: The simple of this FormDataBodyPart.  # noqa: E501
        :type: bool
        """

        self._simple = simple

    @property
    def parameterized_headers(self):
        """Gets the parameterized_headers of this FormDataBodyPart.  # noqa: E501


        :return: The parameterized_headers of this FormDataBodyPart.  # noqa: E501
        :rtype: BodyPartHeaders
        """
        return self._parameterized_headers

    @parameterized_headers.setter
    def parameterized_headers(self, parameterized_headers):
        """Sets the parameterized_headers of this FormDataBodyPart.


        :param parameterized_headers: The parameterized_headers of this FormDataBodyPart.  # noqa: E501
        :type: BodyPartHeaders
        """

        self._parameterized_headers = parameterized_headers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FormDataBodyPart):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from onshape_client.onshape_rest_extras import decode_file_name_from_header

def test_decode_file_name_from_header():
    content_dispostion_header = r"attachment; filename*=UTF-8\\'\\'%43%6F%6E%66%69%67%75%72%61%62%6C%65%20%43%75%62%65%2E%73%74%65%70"
    assert decode_file_name_from_header(content_dispostion_header) == "Configurable Cube.step"
    content_dispostion_header2 = r"form-data; name='field2'; filename='example.txt'"
    assert decode_file_name_from_header(content_dispostion_header2) == "example.txt"


# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTPurchaseUserInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user': 'BTUserBasicSummaryInfo',
        'consumed_quantity': 'int',
        'purchase_state': 'int',
        'purchase': 'BTPurchaseInfo',
        'name': 'str',
        'id': 'str',
        'href': 'str',
        'view_ref': 'str'
    }

    attribute_map = {
        'user': 'user',
        'consumed_quantity': 'consumedQuantity',
        'purchase_state': 'purchaseState',
        'purchase': 'purchase',
        'name': 'name',
        'id': 'id',
        'href': 'href',
        'view_ref': 'viewRef'
    }

    def __init__(self, user=None, consumed_quantity=None, purchase_state=None, purchase=None, name=None, id=None, href=None, view_ref=None):  # noqa: E501
        """BTPurchaseUserInfo - a model defined in OpenAPI"""  # noqa: E501

        self._user = None
        self._consumed_quantity = None
        self._purchase_state = None
        self._purchase = None
        self._name = None
        self._id = None
        self._href = None
        self._view_ref = None
        self.discriminator = None

        if user is not None:
            self.user = user
        if consumed_quantity is not None:
            self.consumed_quantity = consumed_quantity
        if purchase_state is not None:
            self.purchase_state = purchase_state
        if purchase is not None:
            self.purchase = purchase
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if href is not None:
            self.href = href
        if view_ref is not None:
            self.view_ref = view_ref

    @property
    def user(self):
        """Gets the user of this BTPurchaseUserInfo.  # noqa: E501


        :return: The user of this BTPurchaseUserInfo.  # noqa: E501
        :rtype: BTUserBasicSummaryInfo
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this BTPurchaseUserInfo.


        :param user: The user of this BTPurchaseUserInfo.  # noqa: E501
        :type: BTUserBasicSummaryInfo
        """

        self._user = user

    @property
    def consumed_quantity(self):
        """Gets the consumed_quantity of this BTPurchaseUserInfo.  # noqa: E501


        :return: The consumed_quantity of this BTPurchaseUserInfo.  # noqa: E501
        :rtype: int
        """
        return self._consumed_quantity

    @consumed_quantity.setter
    def consumed_quantity(self, consumed_quantity):
        """Sets the consumed_quantity of this BTPurchaseUserInfo.


        :param consumed_quantity: The consumed_quantity of this BTPurchaseUserInfo.  # noqa: E501
        :type: int
        """

        self._consumed_quantity = consumed_quantity

    @property
    def purchase_state(self):
        """Gets the purchase_state of this BTPurchaseUserInfo.  # noqa: E501


        :return: The purchase_state of this BTPurchaseUserInfo.  # noqa: E501
        :rtype: int
        """
        return self._purchase_state

    @purchase_state.setter
    def purchase_state(self, purchase_state):
        """Sets the purchase_state of this BTPurchaseUserInfo.


        :param purchase_state: The purchase_state of this BTPurchaseUserInfo.  # noqa: E501
        :type: int
        """

        self._purchase_state = purchase_state

    @property
    def purchase(self):
        """Gets the purchase of this BTPurchaseUserInfo.  # noqa: E501


        :return: The purchase of this BTPurchaseUserInfo.  # noqa: E501
        :rtype: BTPurchaseInfo
        """
        return self._purchase

    @purchase.setter
    def purchase(self, purchase):
        """Sets the purchase of this BTPurchaseUserInfo.


        :param purchase: The purchase of this BTPurchaseUserInfo.  # noqa: E501
        :type: BTPurchaseInfo
        """

        self._purchase = purchase

    @property
    def name(self):
        """Gets the name of this BTPurchaseUserInfo.  # noqa: E501


        :return: The name of this BTPurchaseUserInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTPurchaseUserInfo.


        :param name: The name of this BTPurchaseUserInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTPurchaseUserInfo.  # noqa: E501


        :return: The id of this BTPurchaseUserInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTPurchaseUserInfo.


        :param id: The id of this BTPurchaseUserInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def href(self):
        """Gets the href of this BTPurchaseUserInfo.  # noqa: E501


        :return: The href of this BTPurchaseUserInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTPurchaseUserInfo.


        :param href: The href of this BTPurchaseUserInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def view_ref(self):
        """Gets the view_ref of this BTPurchaseUserInfo.  # noqa: E501


        :return: The view_ref of this BTPurchaseUserInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_ref

    @view_ref.setter
    def view_ref(self, view_ref):
        """Sets the view_ref of this BTPurchaseUserInfo.


        :param view_ref: The view_ref of this BTPurchaseUserInfo.  # noqa: E501
        :type: str
        """

        self._view_ref = view_ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTPurchaseUserInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTPartAppearanceInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'color': 'BTColorInfo',
        'opacity': 'int',
        'is_generated': 'bool'
    }

    attribute_map = {
        'color': 'color',
        'opacity': 'opacity',
        'is_generated': 'isGenerated'
    }

    def __init__(self, color=None, opacity=None, is_generated=None):  # noqa: E501
        """BTPartAppearanceInfo - a model defined in OpenAPI"""  # noqa: E501

        self._color = None
        self._opacity = None
        self._is_generated = None
        self.discriminator = None

        if color is not None:
            self.color = color
        if opacity is not None:
            self.opacity = opacity
        if is_generated is not None:
            self.is_generated = is_generated

    @property
    def color(self):
        """Gets the color of this BTPartAppearanceInfo.  # noqa: E501


        :return: The color of this BTPartAppearanceInfo.  # noqa: E501
        :rtype: BTColorInfo
        """
        return self._color

    @color.setter
    def color(self, color):
        """Sets the color of this BTPartAppearanceInfo.


        :param color: The color of this BTPartAppearanceInfo.  # noqa: E501
        :type: BTColorInfo
        """

        self._color = color

    @property
    def opacity(self):
        """Gets the opacity of this BTPartAppearanceInfo.  # noqa: E501


        :return: The opacity of this BTPartAppearanceInfo.  # noqa: E501
        :rtype: int
        """
        return self._opacity

    @opacity.setter
    def opacity(self, opacity):
        """Sets the opacity of this BTPartAppearanceInfo.


        :param opacity: The opacity of this BTPartAppearanceInfo.  # noqa: E501
        :type: int
        """

        self._opacity = opacity

    @property
    def is_generated(self):
        """Gets the is_generated of this BTPartAppearanceInfo.  # noqa: E501


        :return: The is_generated of this BTPartAppearanceInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_generated

    @is_generated.setter
    def is_generated(self, is_generated):
        """Sets the is_generated of this BTPartAppearanceInfo.


        :param is_generated: The is_generated of this BTPartAppearanceInfo.  # noqa: E501
        :type: bool
        """

        self._is_generated = is_generated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTPartAppearanceInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTCardInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'billing_address': 'BTAddressInfo',
        'last4': 'str',
        'exp_month': 'int',
        'exp_year': 'int'
    }

    attribute_map = {
        'type': 'type',
        'billing_address': 'billingAddress',
        'last4': 'last4',
        'exp_month': 'expMonth',
        'exp_year': 'expYear'
    }

    def __init__(self, type=None, billing_address=None, last4=None, exp_month=None, exp_year=None):  # noqa: E501
        """BTCardInfo - a model defined in OpenAPI"""  # noqa: E501

        self._type = None
        self._billing_address = None
        self._last4 = None
        self._exp_month = None
        self._exp_year = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if billing_address is not None:
            self.billing_address = billing_address
        if last4 is not None:
            self.last4 = last4
        if exp_month is not None:
            self.exp_month = exp_month
        if exp_year is not None:
            self.exp_year = exp_year

    @property
    def type(self):
        """Gets the type of this BTCardInfo.  # noqa: E501


        :return: The type of this BTCardInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BTCardInfo.


        :param type: The type of this BTCardInfo.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def billing_address(self):
        """Gets the billing_address of this BTCardInfo.  # noqa: E501


        :return: The billing_address of this BTCardInfo.  # noqa: E501
        :rtype: BTAddressInfo
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """Sets the billing_address of this BTCardInfo.


        :param billing_address: The billing_address of this BTCardInfo.  # noqa: E501
        :type: BTAddressInfo
        """

        self._billing_address = billing_address

    @property
    def last4(self):
        """Gets the last4 of this BTCardInfo.  # noqa: E501


        :return: The last4 of this BTCardInfo.  # noqa: E501
        :rtype: str
        """
        return self._last4

    @last4.setter
    def last4(self, last4):
        """Sets the last4 of this BTCardInfo.


        :param last4: The last4 of this BTCardInfo.  # noqa: E501
        :type: str
        """

        self._last4 = last4

    @property
    def exp_month(self):
        """Gets the exp_month of this BTCardInfo.  # noqa: E501


        :return: The exp_month of this BTCardInfo.  # noqa: E501
        :rtype: int
        """
        return self._exp_month

    @exp_month.setter
    def exp_month(self, exp_month):
        """Sets the exp_month of this BTCardInfo.


        :param exp_month: The exp_month of this BTCardInfo.  # noqa: E501
        :type: int
        """

        self._exp_month = exp_month

    @property
    def exp_year(self):
        """Gets the exp_year of this BTCardInfo.  # noqa: E501


        :return: The exp_year of this BTCardInfo.  # noqa: E501
        :rtype: int
        """
        return self._exp_year

    @exp_year.setter
    def exp_year(self, exp_year):
        """Sets the exp_year of this BTCardInfo.


        :param exp_year: The exp_year of this BTCardInfo.  # noqa: E501
        :type: int
        """

        self._exp_year = exp_year

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTCardInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from onshape_client.compatible_imports import parse
from onshape_client.client import Client
import json

import copy
from onshape_client.units import u
from onshape_client.models.bt_configuration_params import BTConfigurationParams
from onshape_client.models.configuration_entry import ConfigurationEntry
import webbrowser


class OnshapeElement(object):
    """ Turn a standard Onshape URL into an OnshapeElement object. Ensure that the URL is correctly formatted, and
    create the useful fields."""

    def __init__(self, url, *args, **kwargs):

        self.client = Client.get_client()

        self.original_url = url
        parsed_vals = parse(url)

        self.base_url = parsed_vals.scheme + "://" + parsed_vals.netloc
        path_list = parsed_vals.path.split('/')
        self.did = path_list[2]
        self.wvmid = path_list[4]
        self.wvm = path_list[3]
        if len(path_list) > 7:
            eid = path_list[8]
            optional_microversion = path_list[6]
        else:
            eid = path_list[6]
            # This is the microversion retrieved from get_microversion_path() and represents a part that is pointing towards
            # both a version/workspace and a microversion.
            optional_microversion = None
        self.eid = eid
        self.optional_microversion = optional_microversion

    def get_microversion_url(self):
        """Determine the microversion from the current version/workspace and return the path to that microversion. This
        will call the API to get the current microversion if the microversion is not already specified."""
        if self.optional_microversion:
            return self.get_url()
        else:
            res = self.client.documents_api.get_current_microversion(self.did,
                                                                     self.wvm,
                                                                     self.wvmid,
                                                                     _preload_content=False)
            microversion = json.loads(res.data.decode("UTF-8"))["microversion"]
            self.optional_microversion = microversion
            return self.get_url()

    def get_url(self):
        optional_microversion_add_in = ""
        if self.optional_microversion:
            optional_microversion_add_in = "/m/" + self.optional_microversion
        return self.base_url + "/documents/" + self.did + "/" + self.wvm + "/" + self.wvmid + optional_microversion_add_in + "/e/" + self.eid


class ConfiguredOnshapeElement(OnshapeElement):

    def __init__(self, *args, **kwargs):
        super(ConfiguredOnshapeElement, self).__init__(*args, **kwargs)
        # Initialize the cached values
        # Raw configuration params
        self._raw_configuration_params = self._get_raw_configuration_params()
        # Map from visible name to parameterId
        self._parameter_map = self._get_parameter_map()
        # Map from parameterId to default value
        self.default_configuration_map = self._get_default_configuration_map()
        # In the beginning, the current configuration is the default config
        self.current_configuration = self.default_configuration_map

    def get_url_with_configuration(self, open_browser=False):
        """A configuration is applied on top of the current element.

        To be used like:
        >>> url = "https://cad.onshape.com/documents/cca81d10f239db0db9481e6f/v/ca51b7554314d6aab254d2e6/e/69c9eedda86512966b20bc90"
        >>> my_element = ConfiguredOnshapeElement(url)
        >>> my_element.update_current_configuration({"size": 20*u.m})
        >>> my_element.get_url_with_configuration()
        https://cad.onshape.com/documents/cca81d10f239db0db9481e6f/v/ca51b7554314d6aab254d2e6/e/69c9eedda86512966b20bc90?configuration=List_UKkGODiz574chc%3DDefault%3Bsize%3D20.0%2Bmeter
        >>> my_element.update_current_configuration({"Configuration": "chamfered"})
        >>> my_element.get_url_with_configuration()
        https://cad.onshape.com/documents/cca81d10f239db0db9481e6f/v/ca51b7554314d6aab254d2e6/e/69c9eedda86512966b20bc90?configuration=List_UKkGODiz574chc%3Dchamfered%3Bsize%3D20.0%2Bmeter
        """
        url = self.get_url() + "?" + self.get_configuration_query_param()
        if open_browser:
            webbrowser.open(url)
        return url

    def update_current_configuration(self, config):
        self.current_configuration.update(config)

    def get_configuration_string(self):
        encoded_val = self._get_configuration_encoding_response()
        return encoded_val["encodedId"]

    def get_configuration_query_param(self):
        encoded_val = self._get_configuration_encoding_response()
        return encoded_val["queryParam"]

    def _get_configuration_encoding_response(self):
        res = self.client.elements_api.encode_configuration_map(self.did, self.eid, self._get_bt_configuration_params_for_current_configuration(), _preload_content=False)
        return json.loads(res.data.decode("utf-8"))

    def _make_configuration_map(self, update):
        return self._get_default_configuration_map().update(update)

    def _get_default_configuration_map(self):
        defaults_map = {}
        for k,v in self._get_parameter_map().items():
            param_type = v["typeName"]
            if param_type == 'BTMConfigurationParameterEnum' or param_type == 'BTMConfigurationParameterBoolean':
                default_value = v["message"]["defaultValue"]
            elif param_type == 'BTMConfigurationParameterQuantity':
                range = v['message']['rangeAndDefault']['message']
                default_value = u(str(range['defaultValue']) + range['units'])
            else:
                raise NotImplementedError("This configuration type: {} is not supported.".format(param_type))
            defaults_map[k] = default_value
        # Return a copy so the original doesn't get changed and we can keep using it
        self.default_configuration_map = defaults_map
        return copy.deepcopy(defaults_map)

    def _get_bt_configuration_params_for_current_configuration(self):
        final = []
        for k, v in self.current_configuration.items():
            p = ConfigurationEntry(parameter_id=self._get_param_id_from_name(k), parameter_value=str(v))
            final.append(p)
        return BTConfigurationParams(parameters=final)

    def _get_param_id_from_name(self, name):
        return self._get_parameter_map()[name]["message"]["parameterId"]

    def _get_parameter_map(self):
        config_params = self._get_raw_configuration_params()
        parameter_map = {}
        for i, p in enumerate(config_params["configurationParameters"]):
            name = config_params["configurationParameters"][i]["message"]["parameterName"]
            parameter_map[name] = config_params["configurationParameters"][i]
        return parameter_map

    def _get_raw_configuration_params(self):
        response =self.client.part_studios_api.get_configuration4(self.did, self.wvm, self.wvmid, self.eid,
                                                        _preload_content=False)
        return json.loads(response.data.decode("utf-8"))







# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTDiscountInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'owner_id': 'str',
        'percent_off': 'int',
        'amount_off': 'int',
        'coupon_type': 'int',
        'coupon_valid_months': 'int',
        'expires_at': 'datetime',
        'created_at': 'datetime',
        'plan_id': 'str',
        'created_by': 'BTUserSummaryInfo',
        'used_at': 'datetime',
        'trial_end_date': 'str',
        'account_balance': 'int',
        'name': 'str',
        'id': 'str',
        'href': 'str',
        'view_ref': 'str'
    }

    attribute_map = {
        'owner_id': 'ownerId',
        'percent_off': 'percentOff',
        'amount_off': 'amountOff',
        'coupon_type': 'couponType',
        'coupon_valid_months': 'couponValidMonths',
        'expires_at': 'expiresAt',
        'created_at': 'createdAt',
        'plan_id': 'planId',
        'created_by': 'createdBy',
        'used_at': 'usedAt',
        'trial_end_date': 'trialEndDate',
        'account_balance': 'accountBalance',
        'name': 'name',
        'id': 'id',
        'href': 'href',
        'view_ref': 'viewRef'
    }

    def __init__(self, owner_id=None, percent_off=None, amount_off=None, coupon_type=None, coupon_valid_months=None, expires_at=None, created_at=None, plan_id=None, created_by=None, used_at=None, trial_end_date=None, account_balance=None, name=None, id=None, href=None, view_ref=None):  # noqa: E501
        """BTDiscountInfo - a model defined in OpenAPI"""  # noqa: E501

        self._owner_id = None
        self._percent_off = None
        self._amount_off = None
        self._coupon_type = None
        self._coupon_valid_months = None
        self._expires_at = None
        self._created_at = None
        self._plan_id = None
        self._created_by = None
        self._used_at = None
        self._trial_end_date = None
        self._account_balance = None
        self._name = None
        self._id = None
        self._href = None
        self._view_ref = None
        self.discriminator = None

        if owner_id is not None:
            self.owner_id = owner_id
        if percent_off is not None:
            self.percent_off = percent_off
        if amount_off is not None:
            self.amount_off = amount_off
        if coupon_type is not None:
            self.coupon_type = coupon_type
        if coupon_valid_months is not None:
            self.coupon_valid_months = coupon_valid_months
        if expires_at is not None:
            self.expires_at = expires_at
        if created_at is not None:
            self.created_at = created_at
        if plan_id is not None:
            self.plan_id = plan_id
        if created_by is not None:
            self.created_by = created_by
        if used_at is not None:
            self.used_at = used_at
        if trial_end_date is not None:
            self.trial_end_date = trial_end_date
        if account_balance is not None:
            self.account_balance = account_balance
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if href is not None:
            self.href = href
        if view_ref is not None:
            self.view_ref = view_ref

    @property
    def owner_id(self):
        """Gets the owner_id of this BTDiscountInfo.  # noqa: E501


        :return: The owner_id of this BTDiscountInfo.  # noqa: E501
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this BTDiscountInfo.


        :param owner_id: The owner_id of this BTDiscountInfo.  # noqa: E501
        :type: str
        """

        self._owner_id = owner_id

    @property
    def percent_off(self):
        """Gets the percent_off of this BTDiscountInfo.  # noqa: E501


        :return: The percent_off of this BTDiscountInfo.  # noqa: E501
        :rtype: int
        """
        return self._percent_off

    @percent_off.setter
    def percent_off(self, percent_off):
        """Sets the percent_off of this BTDiscountInfo.


        :param percent_off: The percent_off of this BTDiscountInfo.  # noqa: E501
        :type: int
        """

        self._percent_off = percent_off

    @property
    def amount_off(self):
        """Gets the amount_off of this BTDiscountInfo.  # noqa: E501


        :return: The amount_off of this BTDiscountInfo.  # noqa: E501
        :rtype: int
        """
        return self._amount_off

    @amount_off.setter
    def amount_off(self, amount_off):
        """Sets the amount_off of this BTDiscountInfo.


        :param amount_off: The amount_off of this BTDiscountInfo.  # noqa: E501
        :type: int
        """

        self._amount_off = amount_off

    @property
    def coupon_type(self):
        """Gets the coupon_type of this BTDiscountInfo.  # noqa: E501


        :return: The coupon_type of this BTDiscountInfo.  # noqa: E501
        :rtype: int
        """
        return self._coupon_type

    @coupon_type.setter
    def coupon_type(self, coupon_type):
        """Sets the coupon_type of this BTDiscountInfo.


        :param coupon_type: The coupon_type of this BTDiscountInfo.  # noqa: E501
        :type: int
        """

        self._coupon_type = coupon_type

    @property
    def coupon_valid_months(self):
        """Gets the coupon_valid_months of this BTDiscountInfo.  # noqa: E501


        :return: The coupon_valid_months of this BTDiscountInfo.  # noqa: E501
        :rtype: int
        """
        return self._coupon_valid_months

    @coupon_valid_months.setter
    def coupon_valid_months(self, coupon_valid_months):
        """Sets the coupon_valid_months of this BTDiscountInfo.


        :param coupon_valid_months: The coupon_valid_months of this BTDiscountInfo.  # noqa: E501
        :type: int
        """

        self._coupon_valid_months = coupon_valid_months

    @property
    def expires_at(self):
        """Gets the expires_at of this BTDiscountInfo.  # noqa: E501


        :return: The expires_at of this BTDiscountInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._expires_at

    @expires_at.setter
    def expires_at(self, expires_at):
        """Sets the expires_at of this BTDiscountInfo.


        :param expires_at: The expires_at of this BTDiscountInfo.  # noqa: E501
        :type: datetime
        """

        self._expires_at = expires_at

    @property
    def created_at(self):
        """Gets the created_at of this BTDiscountInfo.  # noqa: E501


        :return: The created_at of this BTDiscountInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this BTDiscountInfo.


        :param created_at: The created_at of this BTDiscountInfo.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def plan_id(self):
        """Gets the plan_id of this BTDiscountInfo.  # noqa: E501


        :return: The plan_id of this BTDiscountInfo.  # noqa: E501
        :rtype: str
        """
        return self._plan_id

    @plan_id.setter
    def plan_id(self, plan_id):
        """Sets the plan_id of this BTDiscountInfo.


        :param plan_id: The plan_id of this BTDiscountInfo.  # noqa: E501
        :type: str
        """

        self._plan_id = plan_id

    @property
    def created_by(self):
        """Gets the created_by of this BTDiscountInfo.  # noqa: E501


        :return: The created_by of this BTDiscountInfo.  # noqa: E501
        :rtype: BTUserSummaryInfo
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this BTDiscountInfo.


        :param created_by: The created_by of this BTDiscountInfo.  # noqa: E501
        :type: BTUserSummaryInfo
        """

        self._created_by = created_by

    @property
    def used_at(self):
        """Gets the used_at of this BTDiscountInfo.  # noqa: E501


        :return: The used_at of this BTDiscountInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._used_at

    @used_at.setter
    def used_at(self, used_at):
        """Sets the used_at of this BTDiscountInfo.


        :param used_at: The used_at of this BTDiscountInfo.  # noqa: E501
        :type: datetime
        """

        self._used_at = used_at

    @property
    def trial_end_date(self):
        """Gets the trial_end_date of this BTDiscountInfo.  # noqa: E501


        :return: The trial_end_date of this BTDiscountInfo.  # noqa: E501
        :rtype: str
        """
        return self._trial_end_date

    @trial_end_date.setter
    def trial_end_date(self, trial_end_date):
        """Sets the trial_end_date of this BTDiscountInfo.


        :param trial_end_date: The trial_end_date of this BTDiscountInfo.  # noqa: E501
        :type: str
        """

        self._trial_end_date = trial_end_date

    @property
    def account_balance(self):
        """Gets the account_balance of this BTDiscountInfo.  # noqa: E501


        :return: The account_balance of this BTDiscountInfo.  # noqa: E501
        :rtype: int
        """
        return self._account_balance

    @account_balance.setter
    def account_balance(self, account_balance):
        """Sets the account_balance of this BTDiscountInfo.


        :param account_balance: The account_balance of this BTDiscountInfo.  # noqa: E501
        :type: int
        """

        self._account_balance = account_balance

    @property
    def name(self):
        """Gets the name of this BTDiscountInfo.  # noqa: E501


        :return: The name of this BTDiscountInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTDiscountInfo.


        :param name: The name of this BTDiscountInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTDiscountInfo.  # noqa: E501


        :return: The id of this BTDiscountInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTDiscountInfo.


        :param id: The id of this BTDiscountInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def href(self):
        """Gets the href of this BTDiscountInfo.  # noqa: E501


        :return: The href of this BTDiscountInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTDiscountInfo.


        :param href: The href of this BTDiscountInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def view_ref(self):
        """Gets the view_ref of this BTDiscountInfo.  # noqa: E501


        :return: The view_ref of this BTDiscountInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_ref

    @view_ref.setter
    def view_ref(self, view_ref):
        """Sets the view_ref of this BTDiscountInfo.


        :param view_ref: The view_ref of this BTDiscountInfo.  # noqa: E501
        :type: str
        """

        self._view_ref = view_ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTDiscountInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTBillingAllowedPlansInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'upgrades': 'list[BTBillingPlanSummaryInfo]',
        'downgrades': 'list[BTBillingPlanSummaryInfo]',
        'current_plan': 'BTBillingPlanSummaryInfo'
    }

    attribute_map = {
        'upgrades': 'upgrades',
        'downgrades': 'downgrades',
        'current_plan': 'currentPlan'
    }

    def __init__(self, upgrades=None, downgrades=None, current_plan=None):  # noqa: E501
        """BTBillingAllowedPlansInfo - a model defined in OpenAPI"""  # noqa: E501

        self._upgrades = None
        self._downgrades = None
        self._current_plan = None
        self.discriminator = None

        if upgrades is not None:
            self.upgrades = upgrades
        if downgrades is not None:
            self.downgrades = downgrades
        if current_plan is not None:
            self.current_plan = current_plan

    @property
    def upgrades(self):
        """Gets the upgrades of this BTBillingAllowedPlansInfo.  # noqa: E501


        :return: The upgrades of this BTBillingAllowedPlansInfo.  # noqa: E501
        :rtype: list[BTBillingPlanSummaryInfo]
        """
        return self._upgrades

    @upgrades.setter
    def upgrades(self, upgrades):
        """Sets the upgrades of this BTBillingAllowedPlansInfo.


        :param upgrades: The upgrades of this BTBillingAllowedPlansInfo.  # noqa: E501
        :type: list[BTBillingPlanSummaryInfo]
        """

        self._upgrades = upgrades

    @property
    def downgrades(self):
        """Gets the downgrades of this BTBillingAllowedPlansInfo.  # noqa: E501


        :return: The downgrades of this BTBillingAllowedPlansInfo.  # noqa: E501
        :rtype: list[BTBillingPlanSummaryInfo]
        """
        return self._downgrades

    @downgrades.setter
    def downgrades(self, downgrades):
        """Sets the downgrades of this BTBillingAllowedPlansInfo.


        :param downgrades: The downgrades of this BTBillingAllowedPlansInfo.  # noqa: E501
        :type: list[BTBillingPlanSummaryInfo]
        """

        self._downgrades = downgrades

    @property
    def current_plan(self):
        """Gets the current_plan of this BTBillingAllowedPlansInfo.  # noqa: E501


        :return: The current_plan of this BTBillingAllowedPlansInfo.  # noqa: E501
        :rtype: BTBillingPlanSummaryInfo
        """
        return self._current_plan

    @current_plan.setter
    def current_plan(self, current_plan):
        """Sets the current_plan of this BTBillingAllowedPlansInfo.


        :param current_plan: The current_plan of this BTBillingAllowedPlansInfo.  # noqa: E501
        :type: BTBillingPlanSummaryInfo
        """

        self._current_plan = current_plan

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTBillingAllowedPlansInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTInAppMessageParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'context': 'int',
        'content': 'list[Content]',
        'description': 'str',
        'content_type': 'int',
        'start_date': 'datetime',
        'end_date': 'datetime',
        'rule_id': 'str',
        'looker_query': 'int',
        'population_task_id': 'str',
        'billing_plan_ids': 'list[str]',
        'domain_type': 'int',
        'show_once': 'bool',
        'display_order': 'int'
    }

    attribute_map = {
        'name': 'name',
        'context': 'context',
        'content': 'content',
        'description': 'description',
        'content_type': 'contentType',
        'start_date': 'startDate',
        'end_date': 'endDate',
        'rule_id': 'ruleId',
        'looker_query': 'lookerQuery',
        'population_task_id': 'populationTaskId',
        'billing_plan_ids': 'billingPlanIds',
        'domain_type': 'domainType',
        'show_once': 'showOnce',
        'display_order': 'displayOrder'
    }

    def __init__(self, name=None, context=None, content=None, description=None, content_type=None, start_date=None, end_date=None, rule_id=None, looker_query=None, population_task_id=None, billing_plan_ids=None, domain_type=None, show_once=None, display_order=None):  # noqa: E501
        """BTInAppMessageParams - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._context = None
        self._content = None
        self._description = None
        self._content_type = None
        self._start_date = None
        self._end_date = None
        self._rule_id = None
        self._looker_query = None
        self._population_task_id = None
        self._billing_plan_ids = None
        self._domain_type = None
        self._show_once = None
        self._display_order = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if context is not None:
            self.context = context
        if content is not None:
            self.content = content
        if description is not None:
            self.description = description
        if content_type is not None:
            self.content_type = content_type
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date
        if rule_id is not None:
            self.rule_id = rule_id
        if looker_query is not None:
            self.looker_query = looker_query
        if population_task_id is not None:
            self.population_task_id = population_task_id
        if billing_plan_ids is not None:
            self.billing_plan_ids = billing_plan_ids
        if domain_type is not None:
            self.domain_type = domain_type
        if show_once is not None:
            self.show_once = show_once
        if display_order is not None:
            self.display_order = display_order

    @property
    def name(self):
        """Gets the name of this BTInAppMessageParams.  # noqa: E501


        :return: The name of this BTInAppMessageParams.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTInAppMessageParams.


        :param name: The name of this BTInAppMessageParams.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def context(self):
        """Gets the context of this BTInAppMessageParams.  # noqa: E501


        :return: The context of this BTInAppMessageParams.  # noqa: E501
        :rtype: int
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this BTInAppMessageParams.


        :param context: The context of this BTInAppMessageParams.  # noqa: E501
        :type: int
        """

        self._context = context

    @property
    def content(self):
        """Gets the content of this BTInAppMessageParams.  # noqa: E501


        :return: The content of this BTInAppMessageParams.  # noqa: E501
        :rtype: list[Content]
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this BTInAppMessageParams.


        :param content: The content of this BTInAppMessageParams.  # noqa: E501
        :type: list[Content]
        """

        self._content = content

    @property
    def description(self):
        """Gets the description of this BTInAppMessageParams.  # noqa: E501


        :return: The description of this BTInAppMessageParams.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTInAppMessageParams.


        :param description: The description of this BTInAppMessageParams.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def content_type(self):
        """Gets the content_type of this BTInAppMessageParams.  # noqa: E501


        :return: The content_type of this BTInAppMessageParams.  # noqa: E501
        :rtype: int
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """Sets the content_type of this BTInAppMessageParams.


        :param content_type: The content_type of this BTInAppMessageParams.  # noqa: E501
        :type: int
        """

        self._content_type = content_type

    @property
    def start_date(self):
        """Gets the start_date of this BTInAppMessageParams.  # noqa: E501


        :return: The start_date of this BTInAppMessageParams.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this BTInAppMessageParams.


        :param start_date: The start_date of this BTInAppMessageParams.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this BTInAppMessageParams.  # noqa: E501


        :return: The end_date of this BTInAppMessageParams.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this BTInAppMessageParams.


        :param end_date: The end_date of this BTInAppMessageParams.  # noqa: E501
        :type: datetime
        """

        self._end_date = end_date

    @property
    def rule_id(self):
        """Gets the rule_id of this BTInAppMessageParams.  # noqa: E501


        :return: The rule_id of this BTInAppMessageParams.  # noqa: E501
        :rtype: str
        """
        return self._rule_id

    @rule_id.setter
    def rule_id(self, rule_id):
        """Sets the rule_id of this BTInAppMessageParams.


        :param rule_id: The rule_id of this BTInAppMessageParams.  # noqa: E501
        :type: str
        """

        self._rule_id = rule_id

    @property
    def looker_query(self):
        """Gets the looker_query of this BTInAppMessageParams.  # noqa: E501


        :return: The looker_query of this BTInAppMessageParams.  # noqa: E501
        :rtype: int
        """
        return self._looker_query

    @looker_query.setter
    def looker_query(self, looker_query):
        """Sets the looker_query of this BTInAppMessageParams.


        :param looker_query: The looker_query of this BTInAppMessageParams.  # noqa: E501
        :type: int
        """

        self._looker_query = looker_query

    @property
    def population_task_id(self):
        """Gets the population_task_id of this BTInAppMessageParams.  # noqa: E501


        :return: The population_task_id of this BTInAppMessageParams.  # noqa: E501
        :rtype: str
        """
        return self._population_task_id

    @population_task_id.setter
    def population_task_id(self, population_task_id):
        """Sets the population_task_id of this BTInAppMessageParams.


        :param population_task_id: The population_task_id of this BTInAppMessageParams.  # noqa: E501
        :type: str
        """

        self._population_task_id = population_task_id

    @property
    def billing_plan_ids(self):
        """Gets the billing_plan_ids of this BTInAppMessageParams.  # noqa: E501


        :return: The billing_plan_ids of this BTInAppMessageParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._billing_plan_ids

    @billing_plan_ids.setter
    def billing_plan_ids(self, billing_plan_ids):
        """Sets the billing_plan_ids of this BTInAppMessageParams.


        :param billing_plan_ids: The billing_plan_ids of this BTInAppMessageParams.  # noqa: E501
        :type: list[str]
        """

        self._billing_plan_ids = billing_plan_ids

    @property
    def domain_type(self):
        """Gets the domain_type of this BTInAppMessageParams.  # noqa: E501


        :return: The domain_type of this BTInAppMessageParams.  # noqa: E501
        :rtype: int
        """
        return self._domain_type

    @domain_type.setter
    def domain_type(self, domain_type):
        """Sets the domain_type of this BTInAppMessageParams.


        :param domain_type: The domain_type of this BTInAppMessageParams.  # noqa: E501
        :type: int
        """

        self._domain_type = domain_type

    @property
    def show_once(self):
        """Gets the show_once of this BTInAppMessageParams.  # noqa: E501


        :return: The show_once of this BTInAppMessageParams.  # noqa: E501
        :rtype: bool
        """
        return self._show_once

    @show_once.setter
    def show_once(self, show_once):
        """Sets the show_once of this BTInAppMessageParams.


        :param show_once: The show_once of this BTInAppMessageParams.  # noqa: E501
        :type: bool
        """

        self._show_once = show_once

    @property
    def display_order(self):
        """Gets the display_order of this BTInAppMessageParams.  # noqa: E501


        :return: The display_order of this BTInAppMessageParams.  # noqa: E501
        :rtype: int
        """
        return self._display_order

    @display_order.setter
    def display_order(self, display_order):
        """Sets the display_order of this BTInAppMessageParams.


        :param display_order: The display_order of this BTInAppMessageParams.  # noqa: E501
        :type: int
        """

        self._display_order = display_order

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTInAppMessageParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTProjectInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'permission_set': 'BTPermissionSet',
        'permission_scheme': 'BTRbacPermissionSchemeInfo',
        'role_map_entries': 'list[RoleMapEntry]',
        'trash': 'bool',
        'owner': 'BTOwnerInfo',
        'description': 'str',
        'tree_href': 'str',
        'is_mutable': 'bool',
        'resource_type': 'str',
        'created_at': 'datetime',
        'created_by': 'BTUserBasicSummaryInfo',
        'modified_by': 'BTUserBasicSummaryInfo',
        'modified_at': 'datetime',
        'project_id': 'str',
        'can_move': 'bool',
        'is_container': 'bool',
        'is_enterprise_owned': 'bool',
        'has_pending_owner': 'bool',
        'name': 'str',
        'id': 'str',
        'href': 'str',
        'view_ref': 'str'
    }

    attribute_map = {
        'permission_set': 'permissionSet',
        'permission_scheme': 'permissionScheme',
        'role_map_entries': 'roleMapEntries',
        'trash': 'trash',
        'owner': 'owner',
        'description': 'description',
        'tree_href': 'treeHref',
        'is_mutable': 'isMutable',
        'resource_type': 'resourceType',
        'created_at': 'createdAt',
        'created_by': 'createdBy',
        'modified_by': 'modifiedBy',
        'modified_at': 'modifiedAt',
        'project_id': 'projectId',
        'can_move': 'canMove',
        'is_container': 'isContainer',
        'is_enterprise_owned': 'isEnterpriseOwned',
        'has_pending_owner': 'hasPendingOwner',
        'name': 'name',
        'id': 'id',
        'href': 'href',
        'view_ref': 'viewRef'
    }

    def __init__(self, permission_set=None, permission_scheme=None, role_map_entries=None, trash=None, owner=None, description=None, tree_href=None, is_mutable=None, resource_type=None, created_at=None, created_by=None, modified_by=None, modified_at=None, project_id=None, can_move=None, is_container=None, is_enterprise_owned=None, has_pending_owner=None, name=None, id=None, href=None, view_ref=None):  # noqa: E501
        """BTProjectInfo - a model defined in OpenAPI"""  # noqa: E501

        self._permission_set = None
        self._permission_scheme = None
        self._role_map_entries = None
        self._trash = None
        self._owner = None
        self._description = None
        self._tree_href = None
        self._is_mutable = None
        self._resource_type = None
        self._created_at = None
        self._created_by = None
        self._modified_by = None
        self._modified_at = None
        self._project_id = None
        self._can_move = None
        self._is_container = None
        self._is_enterprise_owned = None
        self._has_pending_owner = None
        self._name = None
        self._id = None
        self._href = None
        self._view_ref = None
        self.discriminator = None

        if permission_set is not None:
            self.permission_set = permission_set
        if permission_scheme is not None:
            self.permission_scheme = permission_scheme
        if role_map_entries is not None:
            self.role_map_entries = role_map_entries
        if trash is not None:
            self.trash = trash
        if owner is not None:
            self.owner = owner
        if description is not None:
            self.description = description
        if tree_href is not None:
            self.tree_href = tree_href
        if is_mutable is not None:
            self.is_mutable = is_mutable
        if resource_type is not None:
            self.resource_type = resource_type
        if created_at is not None:
            self.created_at = created_at
        if created_by is not None:
            self.created_by = created_by
        if modified_by is not None:
            self.modified_by = modified_by
        if modified_at is not None:
            self.modified_at = modified_at
        if project_id is not None:
            self.project_id = project_id
        if can_move is not None:
            self.can_move = can_move
        if is_container is not None:
            self.is_container = is_container
        if is_enterprise_owned is not None:
            self.is_enterprise_owned = is_enterprise_owned
        if has_pending_owner is not None:
            self.has_pending_owner = has_pending_owner
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if href is not None:
            self.href = href
        if view_ref is not None:
            self.view_ref = view_ref

    @property
    def permission_set(self):
        """Gets the permission_set of this BTProjectInfo.  # noqa: E501


        :return: The permission_set of this BTProjectInfo.  # noqa: E501
        :rtype: BTPermissionSet
        """
        return self._permission_set

    @permission_set.setter
    def permission_set(self, permission_set):
        """Sets the permission_set of this BTProjectInfo.


        :param permission_set: The permission_set of this BTProjectInfo.  # noqa: E501
        :type: BTPermissionSet
        """

        self._permission_set = permission_set

    @property
    def permission_scheme(self):
        """Gets the permission_scheme of this BTProjectInfo.  # noqa: E501


        :return: The permission_scheme of this BTProjectInfo.  # noqa: E501
        :rtype: BTRbacPermissionSchemeInfo
        """
        return self._permission_scheme

    @permission_scheme.setter
    def permission_scheme(self, permission_scheme):
        """Sets the permission_scheme of this BTProjectInfo.


        :param permission_scheme: The permission_scheme of this BTProjectInfo.  # noqa: E501
        :type: BTRbacPermissionSchemeInfo
        """

        self._permission_scheme = permission_scheme

    @property
    def role_map_entries(self):
        """Gets the role_map_entries of this BTProjectInfo.  # noqa: E501


        :return: The role_map_entries of this BTProjectInfo.  # noqa: E501
        :rtype: list[RoleMapEntry]
        """
        return self._role_map_entries

    @role_map_entries.setter
    def role_map_entries(self, role_map_entries):
        """Sets the role_map_entries of this BTProjectInfo.


        :param role_map_entries: The role_map_entries of this BTProjectInfo.  # noqa: E501
        :type: list[RoleMapEntry]
        """

        self._role_map_entries = role_map_entries

    @property
    def trash(self):
        """Gets the trash of this BTProjectInfo.  # noqa: E501


        :return: The trash of this BTProjectInfo.  # noqa: E501
        :rtype: bool
        """
        return self._trash

    @trash.setter
    def trash(self, trash):
        """Sets the trash of this BTProjectInfo.


        :param trash: The trash of this BTProjectInfo.  # noqa: E501
        :type: bool
        """

        self._trash = trash

    @property
    def owner(self):
        """Gets the owner of this BTProjectInfo.  # noqa: E501


        :return: The owner of this BTProjectInfo.  # noqa: E501
        :rtype: BTOwnerInfo
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this BTProjectInfo.


        :param owner: The owner of this BTProjectInfo.  # noqa: E501
        :type: BTOwnerInfo
        """

        self._owner = owner

    @property
    def description(self):
        """Gets the description of this BTProjectInfo.  # noqa: E501


        :return: The description of this BTProjectInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTProjectInfo.


        :param description: The description of this BTProjectInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def tree_href(self):
        """Gets the tree_href of this BTProjectInfo.  # noqa: E501


        :return: The tree_href of this BTProjectInfo.  # noqa: E501
        :rtype: str
        """
        return self._tree_href

    @tree_href.setter
    def tree_href(self, tree_href):
        """Sets the tree_href of this BTProjectInfo.


        :param tree_href: The tree_href of this BTProjectInfo.  # noqa: E501
        :type: str
        """

        self._tree_href = tree_href

    @property
    def is_mutable(self):
        """Gets the is_mutable of this BTProjectInfo.  # noqa: E501


        :return: The is_mutable of this BTProjectInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_mutable

    @is_mutable.setter
    def is_mutable(self, is_mutable):
        """Sets the is_mutable of this BTProjectInfo.


        :param is_mutable: The is_mutable of this BTProjectInfo.  # noqa: E501
        :type: bool
        """

        self._is_mutable = is_mutable

    @property
    def resource_type(self):
        """Gets the resource_type of this BTProjectInfo.  # noqa: E501


        :return: The resource_type of this BTProjectInfo.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this BTProjectInfo.


        :param resource_type: The resource_type of this BTProjectInfo.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def created_at(self):
        """Gets the created_at of this BTProjectInfo.  # noqa: E501


        :return: The created_at of this BTProjectInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this BTProjectInfo.


        :param created_at: The created_at of this BTProjectInfo.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def created_by(self):
        """Gets the created_by of this BTProjectInfo.  # noqa: E501


        :return: The created_by of this BTProjectInfo.  # noqa: E501
        :rtype: BTUserBasicSummaryInfo
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this BTProjectInfo.


        :param created_by: The created_by of this BTProjectInfo.  # noqa: E501
        :type: BTUserBasicSummaryInfo
        """

        self._created_by = created_by

    @property
    def modified_by(self):
        """Gets the modified_by of this BTProjectInfo.  # noqa: E501


        :return: The modified_by of this BTProjectInfo.  # noqa: E501
        :rtype: BTUserBasicSummaryInfo
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this BTProjectInfo.


        :param modified_by: The modified_by of this BTProjectInfo.  # noqa: E501
        :type: BTUserBasicSummaryInfo
        """

        self._modified_by = modified_by

    @property
    def modified_at(self):
        """Gets the modified_at of this BTProjectInfo.  # noqa: E501


        :return: The modified_at of this BTProjectInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this BTProjectInfo.


        :param modified_at: The modified_at of this BTProjectInfo.  # noqa: E501
        :type: datetime
        """

        self._modified_at = modified_at

    @property
    def project_id(self):
        """Gets the project_id of this BTProjectInfo.  # noqa: E501


        :return: The project_id of this BTProjectInfo.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this BTProjectInfo.


        :param project_id: The project_id of this BTProjectInfo.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def can_move(self):
        """Gets the can_move of this BTProjectInfo.  # noqa: E501


        :return: The can_move of this BTProjectInfo.  # noqa: E501
        :rtype: bool
        """
        return self._can_move

    @can_move.setter
    def can_move(self, can_move):
        """Sets the can_move of this BTProjectInfo.


        :param can_move: The can_move of this BTProjectInfo.  # noqa: E501
        :type: bool
        """

        self._can_move = can_move

    @property
    def is_container(self):
        """Gets the is_container of this BTProjectInfo.  # noqa: E501


        :return: The is_container of this BTProjectInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_container

    @is_container.setter
    def is_container(self, is_container):
        """Sets the is_container of this BTProjectInfo.


        :param is_container: The is_container of this BTProjectInfo.  # noqa: E501
        :type: bool
        """

        self._is_container = is_container

    @property
    def is_enterprise_owned(self):
        """Gets the is_enterprise_owned of this BTProjectInfo.  # noqa: E501


        :return: The is_enterprise_owned of this BTProjectInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_enterprise_owned

    @is_enterprise_owned.setter
    def is_enterprise_owned(self, is_enterprise_owned):
        """Sets the is_enterprise_owned of this BTProjectInfo.


        :param is_enterprise_owned: The is_enterprise_owned of this BTProjectInfo.  # noqa: E501
        :type: bool
        """

        self._is_enterprise_owned = is_enterprise_owned

    @property
    def has_pending_owner(self):
        """Gets the has_pending_owner of this BTProjectInfo.  # noqa: E501


        :return: The has_pending_owner of this BTProjectInfo.  # noqa: E501
        :rtype: bool
        """
        return self._has_pending_owner

    @has_pending_owner.setter
    def has_pending_owner(self, has_pending_owner):
        """Sets the has_pending_owner of this BTProjectInfo.


        :param has_pending_owner: The has_pending_owner of this BTProjectInfo.  # noqa: E501
        :type: bool
        """

        self._has_pending_owner = has_pending_owner

    @property
    def name(self):
        """Gets the name of this BTProjectInfo.  # noqa: E501


        :return: The name of this BTProjectInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTProjectInfo.


        :param name: The name of this BTProjectInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTProjectInfo.  # noqa: E501


        :return: The id of this BTProjectInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTProjectInfo.


        :param id: The id of this BTProjectInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def href(self):
        """Gets the href of this BTProjectInfo.  # noqa: E501


        :return: The href of this BTProjectInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTProjectInfo.


        :param href: The href of this BTProjectInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def view_ref(self):
        """Gets the view_ref of this BTProjectInfo.  # noqa: E501


        :return: The view_ref of this BTProjectInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_ref

    @view_ref.setter
    def view_ref(self, view_ref):
        """Sets the view_ref of this BTProjectInfo.


        :param view_ref: The view_ref of this BTProjectInfo.  # noqa: E501
        :type: str
        """

        self._view_ref = view_ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTProjectInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTSurfaceDescription(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'type_id': 'int',
        'connection_source': 'BTConnection',
        'export_type_name': 'str',
        'unknown_class': 'bool'
    }

    attribute_map = {
        'type': 'type',
        'type_id': 'typeId',
        'connection_source': 'connectionSource',
        'export_type_name': 'exportTypeName',
        'unknown_class': 'unknownClass'
    }

    def __init__(self, type=None, type_id=None, connection_source=None, export_type_name=None, unknown_class=None):  # noqa: E501
        """BTSurfaceDescription - a model defined in OpenAPI"""  # noqa: E501

        self._type = None
        self._type_id = None
        self._connection_source = None
        self._export_type_name = None
        self._unknown_class = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if type_id is not None:
            self.type_id = type_id
        if connection_source is not None:
            self.connection_source = connection_source
        if export_type_name is not None:
            self.export_type_name = export_type_name
        if unknown_class is not None:
            self.unknown_class = unknown_class

    @property
    def type(self):
        """Gets the type of this BTSurfaceDescription.  # noqa: E501


        :return: The type of this BTSurfaceDescription.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BTSurfaceDescription.


        :param type: The type of this BTSurfaceDescription.  # noqa: E501
        :type: str
        """
        allowed_values = ["PLANE", "CYLINDER", "CONE", "SPHERE", "TORUS", "SPUN", "SWEEP", "OFFSET", "BLEND", "BSURFACE", "OTHER", "UNKNOWN"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def type_id(self):
        """Gets the type_id of this BTSurfaceDescription.  # noqa: E501


        :return: The type_id of this BTSurfaceDescription.  # noqa: E501
        :rtype: int
        """
        return self._type_id

    @type_id.setter
    def type_id(self, type_id):
        """Sets the type_id of this BTSurfaceDescription.


        :param type_id: The type_id of this BTSurfaceDescription.  # noqa: E501
        :type: int
        """

        self._type_id = type_id

    @property
    def connection_source(self):
        """Gets the connection_source of this BTSurfaceDescription.  # noqa: E501


        :return: The connection_source of this BTSurfaceDescription.  # noqa: E501
        :rtype: BTConnection
        """
        return self._connection_source

    @connection_source.setter
    def connection_source(self, connection_source):
        """Sets the connection_source of this BTSurfaceDescription.


        :param connection_source: The connection_source of this BTSurfaceDescription.  # noqa: E501
        :type: BTConnection
        """

        self._connection_source = connection_source

    @property
    def export_type_name(self):
        """Gets the export_type_name of this BTSurfaceDescription.  # noqa: E501


        :return: The export_type_name of this BTSurfaceDescription.  # noqa: E501
        :rtype: str
        """
        return self._export_type_name

    @export_type_name.setter
    def export_type_name(self, export_type_name):
        """Sets the export_type_name of this BTSurfaceDescription.


        :param export_type_name: The export_type_name of this BTSurfaceDescription.  # noqa: E501
        :type: str
        """

        self._export_type_name = export_type_name

    @property
    def unknown_class(self):
        """Gets the unknown_class of this BTSurfaceDescription.  # noqa: E501


        :return: The unknown_class of this BTSurfaceDescription.  # noqa: E501
        :rtype: bool
        """
        return self._unknown_class

    @unknown_class.setter
    def unknown_class(self, unknown_class):
        """Sets the unknown_class of this BTSurfaceDescription.


        :param unknown_class: The unknown_class of this BTSurfaceDescription.  # noqa: E501
        :type: bool
        """

        self._unknown_class = unknown_class

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTSurfaceDescription):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
